# Description

Passionné par la programmation et le développement en Python, je crée une bibliothèque personnalisée pour renforcer mes compétences, améliorer ma productivité et partager mon expertise avec la communauté.

# Installation

- **Avec GitHub :**

  ```bash
  git clone https://github.com/Harlequelrah/Library-ElrahPy
  ```

  ```python
  pip install -e "Library-ElrahPy/elrahpy"
  ```

- **Avec pip :**

  ```bash
  pip install elrahpy
  ```

# Documentation

Toute la documentation se trouve dans le /docs
et sur `https://harlequelrah.github.io/Library-ElrahPy/docs/documentation`

## Test

Dans le repertoire tests se trouvent l'arborescence pour l'ensemble les tests de la bibliothèque.

Pour les lancer :

```cmd
pytest
```

ou encore

```cmd
pytest -v -s
```

## Contact ou Support

Pour des questions ou du support, contactez-moi à maximeatsoudegbovi@gmail.com ou au (+228) 91 36 10 29.
